@@ -1,8 +1,8 @@
-#' Color Palette
+#' Color Schemes
 #'
 #' Provides qualitative, diverging and sequential color schemes.
-#' @param palette A [`character`] string giving the name of the palette to be
-#'  used (see below).
+#' @param palette A [`character`] string giving the name of the scheme to be
+#'  used (see [info()]).
 #' @param reverse A [`logical`] scalar: should the resulting vector of colors
 #'  should be reversed?
 #' @param names A [`logical`] scalar: should the names of the colors should be
@@ -14,69 +14,11 @@
 #'  schemes, as they are designed to be used as is to remain color-blind safe.
 #' @param ... Further arguments passed to
 #'  [colorRampPalette][grDevices::colorRamp].
-#' @section Paul Tol's Color Schemes:
-#'  The following palettes are available. The maximum number of supported
-#'  colors is in brackets, this value is only relevant for the qualitative
-#'  color schemes (divergent and sequential schemes are linearly interpolated).
-#'  \describe{
-#'   \item{Qualitative data}{`bright` (7), `high contrast` (3), `vibrant` (7),
-#'   `muted` (9), `medium contrast` (6), `pale` (6), `dark` (6), `light` (9).}
-#'   \item{Diverging data}{`sunset` (11), `nightfall` (17), `BuRd` (9),
-#'   `PRGn` (9).}
-#'   \item{Sequential data}{`YlOrBr` (9), `iridescent` (23), `incandescent`
-#'   (11), `discrete rainbow` (23), `smooth rainbow` (34).}
-#'  }
-#' @section Qualitative Color Schemes:
-#'  According to Paul Tol's technical note, the `bright`, `highcontrast`,
-#'  `vibrant` and `muted` color schemes are color-blind safe. The
-#'  `mediumcontrast` color scheme is designed for situations needing color
-#'  pairs.
+#' @return
+#'  A [`function`] function with the following attributes, that when called
+#'  with a single argument (an [`integer`] specifying the number of colors)
+#'  returns a (named) vector of colors.
 #'
-#'  The `light` color scheme is reasonably distinct for both normal or
-#'  colorblind vision and is intended to fill labeled cells.
-#'
-#'  The `pale` and `dark` schemes are not very distinct in either normal or
-#'  colorblind vision and should be used as a text background or to highlight
-#'  a cell in a table.
-#'
-#'  Refer to the original document for details about the recommended uses (see
-#'  references).
-#' @section Rainbow Color Scheme:
-#'  As a general rule, ordered data should not be represented using a rainbow
-#'  scheme. There are three main arguments against such use (Tol 2018):
-#'  \itemize{
-#'   \item{The spectral order of visible light carries no inherent magnitude
-#'   message.}
-#'   \item{Some bands of almost constant hue with sharp transitions between
-#'   them, can be perceived as jumps in the data.}
-#'   \item{Color-blind people have difficulty distinguishing some colors of
-#'   the rainbow.}
-#'  }
-#'  If such use cannot be avoided, Paul Tol's technical note provides two color
-#'  schemes that are reasonably clear in color-blind vision. To remain
-#'  color-blind safe, these two schemes must comply with the following
-#'  conditions:
-#'  \describe{
-#'   \item{`discreterainbow`}{This scheme must not be interpolated.}
-#'   \item{`smoothrainbow`}{This scheme does not have to be used over the full
-#'   range.}
-#'  }
-#' @section Okabe and Ito Color Scheme:
-#'  The following (qualitative) color scheme is available:
-#'  \describe{
-#'   \item{`okabeito`}{Up to 8 colors.}
-#'   \item{`okabeito black`}{Up to 8 colors, with black as the last.}
-#'  }
-#' @section Scientific Color Schemes:
-#'  The following (qualitative) color schemes are available:
-#'  \describe{
-#'   \item{`stratigraphy`}{International Chronostratigraphic Chart (175 colors).}
-#'   \item{`land`}{AVHRR Global Land Cover Classification (14 colors).}
-#'   \item{`soil`}{FAO Reference Soil Groups (24 colors).}
-#'  }
-#' @return A palette function with the following attributes, that when called
-#'  with a single integer argument (the number of levels) returns a (named)
-#'  vector of colors.
 #'  \describe{
 #'   \item{palette}{A [`character`] string giving the name of the
 #'   color scheme.}
@@ -95,6 +37,14 @@
 #'  to remove a fraction of the color domain (before being interpolated; see
 #'  examples).
 #' @references
+#'  Crameri, F. (2018). Geodynamic diagnostics, scientific visualisation and
+#'  StagLab 3.0. *Geosci. Model Dev.*, 11, 2541-2562.
+#'  \doi{10.5194/gmd-11-2541-2018}
+#'
+#'  Crameri, F., Shephard, G. E. & Heron, P. J. (2020). The misuse of colour in
+#'  science communication. *Nature Communications*, 11, 5444.
+#'  \doi{10.1038/s41467-020-19160-7}
+#'
 #'  Jones, A., Montanarella, L. & Jones, R. (Ed.) (2005). *Soil atlas of
 #'  Europe*. Luxembourg: European Commission, Office for Official Publications
 #'  of the European Communities. 128 pp. ISBN: 92-894-8120-X.
@@ -110,10 +60,10 @@
 #'  \href{https://ccgm.org/}{Commission for the Geological Map of the World}
 #' @example inst/examples/ex-palettes.R
 #' @author N. Frerebeau
-#' @family color palettes
+#' @family color schemes
 #' @keywords color
 #' @export
-colour <- function(palette, reverse = FALSE, names = TRUE, lang = "en",
+colour <- function(palette, reverse = FALSE, names = FALSE, lang = "en",
                    force = FALSE, ...) {
   ## Validation
   palette <- gsub(pattern = "[[:blank:]]", replacement = "", x = palette)
@@ -134,11 +84,12 @@ colour <- function(palette, reverse = FALSE, names = TRUE, lang = "en",
   if (reverse) col_colors <- rev(col_colors)
 
   if (col_interpolate || force) {
+
     ## For color schemes that can be linearly interpolated
     fun <- function(n, range = c(0, 1)) {
       if (missing(n)) n <- k
       # Validate
-      if (any(range > 1) | any(range < 0))
+      if (any(range > 1) || any(range < 0))
         stop(sQuote("range"), " values must be in [0,1].", call. = FALSE)
       # Remove starting colors
       col_colors <- utils::tail(col_colors, k * (1 - range[[1]]))
@@ -154,7 +105,9 @@ colour <- function(palette, reverse = FALSE, names = TRUE, lang = "en",
       )
       return(col)
     }
+
   } else {
+
     ## No interpolation
     ## FIXME: add 'range = c(0, 1)' to prevent "multiple local function
     ## definitions" note in R CMD check
@@ -190,6 +143,7 @@ colour <- function(palette, reverse = FALSE, names = TRUE, lang = "en",
       )
       return(col)
     }
+
   }
   ## Set attributes
   fun <- structure(
